==> haskell-deferred-folds-0.9.18.7-108.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deferred-folds
version:              0.9.18.7
visibility:           public
id:                   deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
key:                  deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  8bd641cd1e3ee3046b47ede2b6c39412
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.18.7-109-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deferred-folds
version:              0.9.18.7
visibility:           public
id:                   deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
key:                  deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  91c15cf0778197aa09e0e679321bd76c
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
